==> libreoffice-fresh-sdk-25.2.3-3-armv7h.pkg.tar.xz: usr/share/doc/libreoffice/sdk/docs/cpp/ref/navtreedata.js <==
/*
 @licstart  The following is the entire license notice for the JavaScript code in this file.

 The MIT License (MIT)

 Copyright (C) 1997-2020 by Dimitri van Heesch

 Permission is hereby granted, free of charge, to any person obtaining a copy of this software
 and associated documentation files (the "Software"), to deal in the Software without restriction,
 including without limitation the rights to use, copy, modify, merge, publish, distribute,
 sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is
 furnished to do so, subject to the following conditions:

 The above copyright notice and this permission notice shall be included in all copies or
 substantial portions of the Software.

 THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING
 BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
 DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

 @licend  The above is the entire license notice for the JavaScript code in this file
*/
var NAVTREE =
[
  [ "LibreOffice", "index.html", [
    [ "SAL debug areas", "a02539.html", [
      [ "SAL", "a02539.html#SAL", null ],
      [ "basctl", "a02539.html#basctl", null ],
      [ "basic", "a02539.html#basic", null ],
      [ "bridges", "a02539.html#bridges", null ],
      [ "canvas", "a02539.html#canvas", null ],
      [ "chart2", "a02539.html#chart2", null ],
      [ "connectivity", "a02539.html#connectivity", null ],
      [ "comphelper", "a02539.html#comphelper", null ],
      [ "cppu", "a02539.html#cppu", null ],
      [ "cppuhelper", "a02539.html#cppuhelper", null ],
      [ "cpputools", "a02539.html#cpputools", null ],
      [ "cui", "a02539.html#cui", null ],
      [ "drawinglayer", "a02539.html#drawinglayer", null ],
      [ "emfio", "a02539.html#emfio", null ],
      [ "Calc", "a02539.html#Calc", null ],
      [ "desktop", "a02539.html#desktop", null ],
      [ "Draw", "a02539.html#Draw", null ],
      [ "editeng", "a02539.html#editeng", null ],
      [ "embeddedobj", "a02539.html#embeddedobj", null ],
      [ "embedserv", "a02539.html#embedserv", null ],
      [ "extensions", "a02539.html#extensions", null ],
      [ "Filter", "a02539.html#Filter", null ],
      [ "oox", "a02539.html#oox", null ],
      [ "forms", "a02539.html#forms", null ],
      [ "formula", "a02539.html#formula", null ],
      [ "fpicker", "a02539.html#fpicker", null ],
      [ "framework", "a02539.html#framework", null ],
      [ "i18nlangtag", "a02539.html#i18nlangtag", null ],
      [ "i18npool", "a02539.html#i18npool", null ],
      [ "i18n", "a02539.html#i18n", null ],
      [ "io", "a02539.html#io", null ],
      [ "jvmfwk", "a02539.html#jvmfwk", null ],
      [ "LanguageTool", "a02539.html#LanguageTool", null ],
      [ "LibreOfficeKit", "a02539.html#LibreOfficeKit", null ],
      [ "l10ntools", "a02539.html#l10ntools", null ],
      [ "Math", "a02539.html#Math", null ],
      [ "package", "a02539.html#package", null ],
      [ "pyuno", "a02539.html#pyuno", null ],
      [ "sdext", "a02539.html#sdext", null ],
      [ "sfx", "a02539.html#sfx", null ],
      [ "slideshow", "a02539.html#slideshow", null ],
      [ "sot", "a02539.html#sot", null ],
      [ "svl", "a02539.html#svl", null ],
      [ "svtools", "a02539.html#svtools", null ],
      [ "svx", "a02539.html#svx", null ],
      [ "toolkit", "a02539.html#toolkit", null ],
      [ "tools", "a02539.html#tools", null ],
      [ "ucb", "a02539.html#ucb", null ],
      [ "unotools", "a02539.html#unotools", null ],
      [ "URE", "a02539.html#URE", null ],
      [ "sax", "a02539.html#sax", null ],
      [ "stoc", "a02539.html#stoc", null ],
      [ "VCL", "a02539.html#VCL", null ],
      [ "winaccessibility", "a02539.html#winaccessibility", null ],
      [ "Writer", "a02539.html#Writer", null ],
      [ "writerfilter", "a02539.html#writerfilter", null ],
      [ "writerperfect", "a02539.html#writerperfect", null ],
      [ "xmloff", "a02539.html#xmloff", null ],
      [ "xmlsecurity", "a02539.html#xmlsecurity", null ],
      [ "xmlscript", "a02539.html#xmlscript", null ],
      [ "dbaccess", "a02539.html#dbaccess", null ],
      [ "avmedia", "a02539.html#avmedia", null ],
      [ "other", "a02539.html#other", null ]
    ] ],
    [ "Basic logging functionality.", "a02540.html", null ],
    [ "Deprecated List", "a00518.html", null ],
    [ "Todo List", "a00519.html", null ],
    [ "Topics", "topics.html", "topics" ],
    [ "Namespaces", "namespaces.html", [
      [ "Namespace List", "namespaces.html", "namespaces_dup" ],
      [ "Namespace Members", "namespacemembers.html", [
        [ "All", "namespacemembers.html", "namespacemembers_dup" ],
        [ "Functions", "namespacemembers_func.html", "namespacemembers_func" ],
        [ "Variables", "namespacemembers_vars.html", null ],
        [ "Typedefs", "namespacemembers_type.html", null ],
        [ "Enumerations", "namespacemembers_enum.html", null ],
        [ "Enumerator", "namespacemembers_eval.html", null ]
      ] ]
    ] ],
    [ "Classes", "annotated.html", [
      [ "Class List", "annotated.html", "annotated_dup" ],
      [ "Class Index", "classes.html", null ],
      [ "Class Hierarchy", "hierarchy.html", "hierarchy" ],
      [ "Class Members", "functions.html", [
        [ "All", "functions.html", "functions_dup" ],
        [ "Functions", "functions_func.html", "functions_func" ],
        [ "Variables", "functions_vars.html", "functions_vars" ],
        [ "Typedefs", "functions_type.html", null ],
        [ "Enumerations", "functions_enum.html", null ],
        [ "Enumerator", "functions_eval.html", null ],
        [ "Related Symbols", "functions_rela.html", null ]
      ] ]
    ] ],
    [ "Files", "files.html", [
      [ "File List", "files.html", "files_dup" ],
      [ "File Members", "globals.html", [
        [ "All", "globals.html", "globals_dup" ],
        [ "Functions", "globals_func.html", "globals_func" ],
        [ "Variables", "globals_vars.html", null ],
        [ "Typedefs", "globals_type.html", null ],
        [ "Enumerations", "globals_enum.html", null ],
        [ "Enumerator", "globals_eval.html", "globals_eval" ],
        [ "Macros", "globals_defs.html", "globals_defs" ]
      ] ]
    ] ]
  ] ]
];

var NAVTREEINDEX =
[
"a00008.html",
"a00095.html#a05aa785ee3a32f3db21471f922fd011b",
"a00110.html#ab15e4181419fc39ef56afb21c79ec78e",
"a00152_source.html",
"a00188.html#a3f3cae5125db4b9a7f912f1dfc7bb40c",
"a00245.html#a9577de89d5c2a6ae4d20dd39245bbe5da594ea049de970744643d81d6d571e090",
"a00290.html#a8dcfda175e467f8077700ffa9fd8b544",
"a00515.html#ac3f10d1dde9a631a2df769c9eefd1fd3",
"a00537.html#a36808dda29a2ec49670b0b872e75fa13",
"a00606.html#a115f3db0d455ed06cb9616880a607223",
"a00662.html#ae7274338240f53943cb4309f4610277f",
"a00734.html#afb15abd4d6bca742613aa55c342f3082",
"a00754.html#a679d95859f010dbfd55f67cf4fa7c6eb",
"a00774.html#ae2e12b95c2df5b6cab62104982151c7ead08d836585f9f9383392cbd856bdc7c5",
"a00818.html#a3540631a0fd1f38e5538f50ea0b2fd37",
"a00858.html#aca87cea7faea35650e1a359ebce49ce4",
"a00954.html#a451809bc746a147b2ecd3caea7cea703",
"a01010.html#a56de184bc83af0a21d396de4c54f405a",
"a01098.html",
"a01218.html",
"a01326.html#abaeb329d0b5d020ff3fec6ad46f4532f",
"a01442.html#a045909a4c1c41b7fb21780558092a640",
"a01554.html#a983d2fa2d5fc7645c3de068de1ecc353",
"a01666.html#a36e3da3d02cb290420c5fa0cd8de6ea4",
"a01770.html#a3605552892f595203d6c331e46afb202",
"a01870.html#abe626386f8d48ae8fb697da4dfdbe487",
"a01930.html#a0e83a0ef7166a3bd1c68efca431a216c",
"a01974.html#af8b93302ae0fd62e3b6c464d211fec34",
"globals_defs_r.html"
];

var SYNCONMSG = 'click to disable panel synchronization';
var SYNCOFFMSG = 'click to enable panel synchronization';

==> libreoffice-fresh-sdk-25.2.5-1-armv7h.pkg.tar.xz: usr/share/doc/libreoffice/sdk/docs/cpp/ref/navtreedata.js <==
/*
 @licstart  The following is the entire license notice for the JavaScript code in this file.

 The MIT License (MIT)

 Copyright (C) 1997-2020 by Dimitri van Heesch

 Permission is hereby granted, free of charge, to any person obtaining a copy of this software
 and associated documentation files (the "Software"), to deal in the Software without restriction,
 including without limitation the rights to use, copy, modify, merge, publish, distribute,
 sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is
 furnished to do so, subject to the following conditions:

 The above copyright notice and this permission notice shall be included in all copies or
 substantial portions of the Software.

 THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING
 BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
 DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

 @licend  The above is the entire license notice for the JavaScript code in this file
*/
var NAVTREE =
[
  [ "LibreOffice", "index.html", [
    [ "SAL debug areas", "a02539.html", [
      [ "SAL", "a02539.html#SAL", null ],
      [ "basctl", "a02539.html#basctl", null ],
      [ "basic", "a02539.html#basic", null ],
      [ "bridges", "a02539.html#bridges", null ],
      [ "canvas", "a02539.html#canvas", null ],
      [ "chart2", "a02539.html#chart2", null ],
      [ "connectivity", "a02539.html#connectivity", null ],
      [ "comphelper", "a02539.html#comphelper", null ],
      [ "cppu", "a02539.html#cppu", null ],
      [ "cppuhelper", "a02539.html#cppuhelper", null ],
      [ "cpputools", "a02539.html#cpputools", null ],
      [ "cui", "a02539.html#cui", null ],
      [ "drawinglayer", "a02539.html#drawinglayer", null ],
      [ "emfio", "a02539.html#emfio", null ],
      [ "Calc", "a02539.html#Calc", null ],
      [ "desktop", "a02539.html#desktop", null ],
      [ "Draw", "a02539.html#Draw", null ],
      [ "editeng", "a02539.html#editeng", null ],
      [ "embeddedobj", "a02539.html#embeddedobj", null ],
      [ "embedserv", "a02539.html#embedserv", null ],
      [ "extensions", "a02539.html#extensions", null ],
      [ "Filter", "a02539.html#Filter", null ],
      [ "oox", "a02539.html#oox", null ],
      [ "forms", "a02539.html#forms", null ],
      [ "formula", "a02539.html#formula", null ],
      [ "fpicker", "a02539.html#fpicker", null ],
      [ "framework", "a02539.html#framework", null ],
      [ "i18nlangtag", "a02539.html#i18nlangtag", null ],
      [ "i18npool", "a02539.html#i18npool", null ],
      [ "i18n", "a02539.html#i18n", null ],
      [ "io", "a02539.html#io", null ],
      [ "jvmfwk", "a02539.html#jvmfwk", null ],
      [ "LanguageTool", "a02539.html#LanguageTool", null ],
      [ "LibreOfficeKit", "a02539.html#LibreOfficeKit", null ],
      [ "l10ntools", "a02539.html#l10ntools", null ],
      [ "Math", "a02539.html#Math", null ],
      [ "package", "a02539.html#package", null ],
      [ "pyuno", "a02539.html#pyuno", null ],
      [ "sdext", "a02539.html#sdext", null ],
      [ "sfx", "a02539.html#sfx", null ],
      [ "slideshow", "a02539.html#slideshow", null ],
      [ "sot", "a02539.html#sot", null ],
      [ "svl", "a02539.html#svl", null ],
      [ "svtools", "a02539.html#svtools", null ],
      [ "svx", "a02539.html#svx", null ],
      [ "toolkit", "a02539.html#toolkit", null ],
      [ "tools", "a02539.html#tools", null ],
      [ "ucb", "a02539.html#ucb", null ],
      [ "unotools", "a02539.html#unotools", null ],
      [ "URE", "a02539.html#URE", null ],
      [ "sax", "a02539.html#sax", null ],
      [ "stoc", "a02539.html#stoc", null ],
      [ "VCL", "a02539.html#VCL", null ],
      [ "winaccessibility", "a02539.html#winaccessibility", null ],
      [ "Writer", "a02539.html#Writer", null ],
      [ "writerfilter", "a02539.html#writerfilter", null ],
      [ "writerperfect", "a02539.html#writerperfect", null ],
      [ "xmloff", "a02539.html#xmloff", null ],
      [ "xmlsecurity", "a02539.html#xmlsecurity", null ],
      [ "xmlscript", "a02539.html#xmlscript", null ],
      [ "dbaccess", "a02539.html#dbaccess", null ],
      [ "avmedia", "a02539.html#avmedia", null ],
      [ "other", "a02539.html#other", null ]
    ] ],
    [ "Basic logging functionality.", "a02540.html", null ],
    [ "Deprecated List", "a00518.html", null ],
    [ "Todo List", "a00519.html", null ],
    [ "Topics", "topics.html", "topics" ],
    [ "Namespaces", "namespaces.html", [
      [ "Namespace List", "namespaces.html", "namespaces_dup" ],
      [ "Namespace Members", "namespacemembers.html", [
        [ "All", "namespacemembers.html", "namespacemembers_dup" ],
        [ "Functions", "namespacemembers_func.html", "namespacemembers_func" ],
        [ "Variables", "namespacemembers_vars.html", null ],
        [ "Typedefs", "namespacemembers_type.html", null ],
        [ "Enumerations", "namespacemembers_enum.html", null ],
        [ "Enumerator", "namespacemembers_eval.html", null ]
      ] ]
    ] ],
    [ "Classes", "annotated.html", [
      [ "Class List", "annotated.html", "annotated_dup" ],
      [ "Class Index", "classes.html", null ],
      [ "Class Hierarchy", "hierarchy.html", "hierarchy" ],
      [ "Class Members", "functions.html", [
        [ "All", "functions.html", "functions_dup" ],
        [ "Functions", "functions_func.html", "functions_func" ],
        [ "Variables", "functions_vars.html", "functions_vars" ],
        [ "Typedefs", "functions_type.html", null ],
        [ "Enumerations", "functions_enum.html", null ],
        [ "Enumerator", "functions_eval.html", null ],
        [ "Related Symbols", "functions_rela.html", null ]
      ] ]
    ] ],
    [ "Files", "files.html", [
      [ "File List", "files.html", "files_dup" ],
      [ "File Members", "globals.html", [
        [ "All", "globals.html", "globals_dup" ],
        [ "Functions", "globals_func.html", "globals_func" ],
        [ "Variables", "globals_vars.html", null ],
        [ "Typedefs", "globals_type.html", null ],
        [ "Enumerations", "globals_enum.html", null ],
        [ "Enumerator", "globals_eval.html", "globals_eval" ],
        [ "Macros", "globals_defs.html", "globals_defs" ]
      ] ]
    ] ]
  ] ]
];

var NAVTREEINDEX =
[
"a00008.html",
"a00068.html#acf465b0cb57ef155f140dc09f126d16da7454c40b8769ddb75ddc347dd7bb2bc6",
"a00104.html#a31a83247509b977c5544fe89dfeefbe9",
"a00143.html#a398f136628f7e39f415edd80e1ab376c",
"a00185.html#acceba46370e547f14519c9a93494b321a35c5d10ebf510564fc1fa036ea1c81f3",
"a00221.html",
"a00287.html#a0b133be6ff6baec319b9aae46c7668eb",
"a00515.html#ac3f10d1dde9a631a2df769c9eefd1fd3",
"a00537.html#a36808dda29a2ec49670b0b872e75fa13",
"a00606.html#a115f3db0d455ed06cb9616880a607223",
"a00662.html#ae7274338240f53943cb4309f4610277f",
"a00734.html#afb15abd4d6bca742613aa55c342f3082",
"a00754.html#a679d95859f010dbfd55f67cf4fa7c6eb",
"a00774.html#ae2e12b95c2df5b6cab62104982151c7ead08d836585f9f9383392cbd856bdc7c5",
"a00818.html#a3540631a0fd1f38e5538f50ea0b2fd37",
"a00858.html#aca87cea7faea35650e1a359ebce49ce4",
"a00954.html#a451809bc746a147b2ecd3caea7cea703",
"a01010.html#a56de184bc83af0a21d396de4c54f405a",
"a01106.html",
"a01226.html",
"a01338.html#a23ae5b2fc8d0f0a76ba87e39126576fa",
"a01442.html#ac607dea78d8f31f2a58e0caad5cb4e6c",
"a01562.html",
"a01674.html#a365fd92cea2fec7167c41be3019e1766",
"a01786.html",
"a01874.html#a929dd79785e30217bc7d53152c1b455a",
"a01930.html#abb8c71eed2ece02ace5aef144003bac4",
"a02539.html#Writer",
"globals_func_u.html"
];

var SYNCONMSG = 'click to disable panel synchronization';
var SYNCOFFMSG = 'click to enable panel synchronization';
var LISTOFALLMEMBERS = 'List of all members';
